Learn R Programming

painbow (version 1.0.1)

painbow_colors: An array of colors from XKCD's painbow comic

Description

This set of 192 colors is the Painbow. The colors were extracted using the pixels from the color bar on the right side of the comic.

Usage

painbow_colors

Arguments

Format

An array with 192 hex color strings.